@@ -2,7 +2,7 @@
 #define SPVM_RUNTIME_ALLOCATOR_H
 #include <stddef.h>
 #include "spvm_base.h"
-#include "spvm_data_api.h"
+#include "spvm_api.h"
 
 // Parser information
 struct SPVM_runtime_allocator {
